@@ -1450,7 +1450,7 @@ gsm_properties_dialog_init (GsmPropertiesDialog *dialog)
         gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
         gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
         gtk_window_set_icon_name (GTK_WINDOW (dialog), "session-properties");
-        gtk_window_set_title (GTK_WINDOW (dialog), _("Sessions Preferences"));
+        gtk_window_set_title (GTK_WINDOW (dialog), _("Startup Applications Preferences"));
 }
 
 static void
